@@ -1,5 +1,5 @@
 from dataclasses import dataclass
-from typing import List
+from typing import Any, List
 
 from tabulate import tabulate
 
@@ -13,21 +13,18 @@ class Table(ReprBase):
     values: List[List[str]]
     has_index: bool = False
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         return self.__tabulate()
 
-    def __tabulate(self, fmt="pretty") -> str:
-        return tabulate(
-            self.values,
-            colalign=[(0, "r")] if self.has_index else None,
-            headers=self.columns,
-            tablefmt=fmt,
-        )
+    def __tabulate(self, fmt: str = "github", values: List[List[Any]] = None) -> str:
+        values = values or self.values
+        return tabulate(values, headers=self.columns, tablefmt=fmt,)
 
-    def _repr_markdown_(self):
-        return self.__tabulate()
+    def _repr_markdown_(self) -> str:
+        values = [[f"**{row[0]}**"] + row[1:] for row in self.values]
+        return self.__tabulate(values=values)
 
-    def _repr_latex_(self):
+    def _repr_latex_(self) -> str:
         return self.__tabulate(fmt="latex")
 
     def _repr_html_(self) -> str:
